.. image:: doc/pySDC_Social_Preview.jpg
  :width: 400
  :alt: pySDC Picture

Overview
========

ISO/IEEE 11073 is a standards family for the communication of medical devices. SDC
(Service-Oriented Device Connectivity) is one of the latest additions to
this family and is `described
here <https://en.wikipedia.org/wiki/IEEE_11073_service-oriented_device_connectivity>`__.

Market-oriented information on SDC from Dräger can be found
`here <https://www.draeger.com/Library/Content/sdc-information-sheet-9107546-en.pdf>`__.

SDC is supported by the interoperability association `OR.Net <https://ornet.org/en>`__.

Getting Started
===============

A tutorial can be found in the tutorial folder.

Usage
=====

The sdc11073 library is not intended for use in medical products. The
focus is on testing and demonstration.

Support
=======

Issues can be filed
`here <https://github.com/Draegerwerk/sdc11073/issues>`__. 

License
=======

See LICENSE file
